Recursion
:::::::::

.. toctree::
   :caption: Recursion
   :maxdepth: 2

   WhatIsRecursion.rst
   CalculatingtheSumofaListofNumbers.rst
   TheThreeLawsofRecursion.rst
   ConvertinganIntegertoaStringinAnyBase.rst
   intro-VisualizingRecursion.rst
   SierpinskiTriangle.rst
   Glossary.rst
   ProgrammingExercises.rst
   Exercises.rst
   
